/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.pluginmgt.cmd;

import java.util.List;

import org.tinygroup.command.CommandGoalExecutor;
import org.tinygroup.command.CommandSystem;
import org.tinygroup.context.Context;
import org.tinygroup.i18n.I18nMessageFactory;
import org.tinygroup.i18n.I18nMessages;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.plugin.PluginManager;
import org.tinygroup.plugin.config.PluginInfo;
import org.tinygroup.plugin.loader.PluginLoader;
import org.tinygroup.plugin.loader.impl.PluginMutiLoader;
import org.tinygroup.plugin.util.PluginUtil;
import org.tinygroup.vfs.FileObject;
import org.tinygroup.vfs.VFS;

/**
 * 列出插件的jar列表
 * @author luoguo
 *
 */

public class PluginJarListCommand implements CommandGoalExecutor {

	private final int JAR_SPACE = 2;
	private final int JAR_DETAIL_SPACE = 4;
	private boolean showDetail;
	private I18nMessages i18nMessages = I18nMessageFactory.geti18nMessages();
	private static Logger logger = LoggerFactory
			.getLogger(PluginJarListCommand.class);

	public boolean isShowDetail() {
		return showDetail;
	}

	public void setShowDetail(boolean showDetail) {
		this.showDetail = showDetail;
	}

	public void execute(CommandSystem commandHelper, Context context) {

		logger.logMessage(LogLevel.DEBUG, "开始执行指令：列出插件目录下所有Jar包");

		String path = context.get(PluginManager.PLUGIN_BASE_DIR);
		if (path == null) {
			path = PluginUtil.getPlguinDir();
		}
		logger.logMessage(LogLevel.DEBUG, "扫描目录为{0}", path);

			FileObject dir = VFS.resolveFile(path);
			
			if ((dir==null)||(dir.getChildren()==null)||(dir.getChildren().size() == 0)) {
				commandHelper.indentPrint(
						i18nMessages.getMessage("pluginmgt.dirIsNull"), 0);
				commandHelper.println();
				return;
			}

			commandHelper.indentPrint(
					i18nMessages.getMessage("pluginmgt.dirContain"), 0);
			commandHelper.println();

			for (FileObject f : dir.getChildren()) {
				showFile(commandHelper, f);
			}


		logger.logMessage(LogLevel.DEBUG, "指令执行完毕：列出插件目录下所有Jar包");
	}

	private void showFile(CommandSystem commandHelper, FileObject f) {
		String pluginsPath = f.getAbsolutePath();
		if (pluginsPath.endsWith(".jar")) {
			commandHelper.indentPrint(f.getFileName(),
					JAR_SPACE);
			commandHelper.println();
			if (showDetail) {
				showFileDetail(commandHelper, f);
			}
		}
	}

	private void showFileDetail(CommandSystem commandHelper, FileObject f) {
		String pluginsPath = f.getAbsolutePath();
		PluginLoader loader = new PluginMutiLoader();
		List<PluginInfo> list = loader.listJar(pluginsPath);
		if(list==null||list.size()==0){
			showNoInfo(commandHelper);;
		}else{
			for (PluginInfo info : list) {
				showPluginsInfo(commandHelper, info);
			}
		}
		
	}

	private void showPluginsInfo(CommandSystem commandHelper, PluginInfo plugin) {
			String info = String.format("插件[id:%s,version:%s]", plugin.getId(),
					plugin.getVersion());
			commandHelper.indentPrint(info, JAR_DETAIL_SPACE);
			commandHelper.println();
	}
	
	private void showNoInfo(CommandSystem commandHelper) {
		String info = String.format("无插件");
		commandHelper.indentPrint(info, JAR_DETAIL_SPACE);
		commandHelper.println();
	}

}
