/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.pluginmgt.cmd;

import java.util.List;

import org.tinygroup.command.CommandGoalExecutor;
import org.tinygroup.command.CommandSystem;
import org.tinygroup.context.Context;
import org.tinygroup.i18n.I18nMessageFactory;
import org.tinygroup.i18n.I18nMessages;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.plugin.PluginManager;
import org.tinygroup.plugin.util.PluginUtil;
import org.tinygroup.springutil.SpringUtil;
import org.tinygroup.vfs.FileObject;
import org.tinygroup.vfs.VFS;

//TODO 由陈佼去修改文件路径的问题
/**
 * 加载插件命令
 * 
 * @author luoguo
 * 
 */
public class PluginJarLoadCommand implements CommandGoalExecutor {

	private static final int JAR_SPACE = 2;
	private String jarName;
	private static Logger logger = LoggerFactory
			.getLogger(PluginJarLoadCommand.class);
	private I18nMessages i18nMessages = I18nMessageFactory.geti18nMessages();

	public String getJarName() {
		return jarName;
	}

	public void setJarName(String jarName) {
		this.jarName = jarName;
	}

	public void execute(CommandSystem commandHelper, Context context) {
		logger.logMessage(LogLevel.DEBUG, "开始执行指令：载入指定插件Jar包[{0}]", jarName);
		String path = context.get(PluginManager.PLUGIN_BASE_DIR);
		if (path == null) {
			path = PluginUtil.getPlguinDir();
		}
		logger.logMessage(LogLevel.DEBUG, "插件根目录为[{0}]", path);
		FileObject jarFile = VFS.resolveFile(path);
		List<FileObject> files = jarFile.getChildren();

		if (files.size() == 0) {
			commandHelper
					.indentPrint(i18nMessages.getMessage(
							"pluginmgt.jarIsNotExist", jarName), 0);
			commandHelper.println();
			return;
		}
		for (FileObject file : files) {
			if (file.getFileName().equals(jarName)) {
				loadJar(commandHelper, context, file);
				return;
			}
		}
		logger.logMessage(LogLevel.DEBUG, "指令执行完毕：载入指定插件Jar包[{0}]", jarName);
	}

	private void loadJar(CommandSystem commandHelper, Context context,
			FileObject fileObject) {
		logger.logMessage(LogLevel.DEBUG, "开始载入插件[{0}]",
				fileObject.getAbsolutePath());
		PluginManager pluginManager = SpringUtil.getBean(
				"pluginManager");
		commandHelper.indentPrint("载入Jar:" + fileObject.getAbsolutePath(),
				JAR_SPACE);
		commandHelper.println();
		pluginManager.load(fileObject.getAbsolutePath());
		logger.logMessage(LogLevel.DEBUG, "载入插件[{0}]结束",
				fileObject.getAbsolutePath());
	}

}
